@@ -45,7 +45,7 @@ use std::fmt;
 /// See the documentation for the `Command` struct methods and fields to learn how to use the parsed data in your command line interface application logic.
 #[derive(Debug)]
 pub struct Command {
-    /// Vector of command line strings defined on instantiation
+    /// Vector of ordered command line arguments
     pub argv: Vec<String>,
     /// number of strings in `Command.argv`
     pub argc: usize,
@@ -59,6 +59,8 @@ pub struct Command {
     pub first_arg: Option<String>,
     /// `Option<String>` of last positional argument to the executable. `None` if there are no arguments to the executable.
     pub last_arg: Option<String>,
+    // `Option<Vec<String>>` of ordered arguments that follow a double dash command line idiom.  The double dash idiom indicates that no subsequent argument should be parsed as an option. `None` if there a double dash argument is not present or there are no arguments after the double dash argument.
+    pub double_dash_argv: Option<Vec<String>>,
 }
 
 // Traits
@@ -75,18 +77,6 @@ impl fmt::Display for Command {
     }
 }
 
-// // Debug trait
-// impl fmt::Debug for Command {
-//     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-//         let mut commandstring = String::new();
-//         for substring in &self.argv {
-//             commandstring.push_str(&substring[..]);
-//             commandstring.push_str(" ");
-//         }
-//         write!(f, "Command: '{}'", &commandstring[..].trim_right())
-//     }
-// }
-
 // Methods
 impl Command {
     /// Instantiates and returns a new `Command` struct with the command line argument data in `std::env::args().collect()`
@@ -127,6 +117,7 @@ impl Command {
         let definitions_hm = parsers::parse_definitions(&arguments);
         let first_arg_definition = parsers::parse_first_arg(&arguments);
         let last_arg_definition = parsers::parse_last_arg(&arguments);
+        let double_dash_definition = parsers::parse_double_dash_args(&arguments);
 
         Command {
             argv: arguments_definition,
@@ -136,6 +127,7 @@ impl Command {
             definitions: definitions_hm,
             first_arg: first_arg_definition,
             last_arg: last_arg_definition,
+            double_dash_argv: double_dash_definition,
         }
     }
 
@@ -476,6 +468,44 @@ mod tests {
         assert_eq!(c.last_arg, None);
     }
 
+    #[test]
+    fn command_instantiation_double_dash_argv() {
+        let c = Command::new_with_vec(vec![
+            "test".to_string(),
+            "--something".to_string(),
+            "--option=define".to_string(),
+            "--another=otherdef".to_string(),
+            "--".to_string(),
+            "--double".to_string(),
+            "lastpos".to_string(),
+        ]);
+        let expected_vec = vec![String::from("--double"), String::from("lastpos")];
+        assert_eq!(c.double_dash_argv, Some(expected_vec));
+    }
+
+    #[test]
+    fn command_instantiation_double_dash_argv_no_args() {
+        let c = Command::new_with_vec(vec![
+            "test".to_string(),
+            "--something".to_string(),
+            "--option=define".to_string(),
+            "--another=otherdef".to_string(),
+            "--".to_string(),
+        ]);
+        assert_eq!(c.double_dash_argv, None);
+    }
+
+    #[test]
+    fn command_instantiation_double_dash_argv_no_double_dash() {
+        let c = Command::new_with_vec(vec![
+            "test".to_string(),
+            "--something".to_string(),
+            "--option=define".to_string(),
+            "--another=otherdef".to_string(),
+        ]);
+        assert_eq!(c.double_dash_argv, None);
+    }
+
     #[test]
     fn command_method_has_args_true() {
         let c = Command::new_with_vec(vec!["test".to_string(), "--help".to_string()]);
